@@ -56,7 +56,7 @@ class PyPackerDetect:
                     d['packer'].append(n)
             except UnicodeDecodeError:
                 d['bad'].append(n)
-                continue
+                __add(1, "Section name with invalid characters")
         # bad entry point sections
         __intersect = lambda l1, l2: len(set(l1).intersection(l2)) > 0
         if self.__config['bad_ep_sec']:
